==> adfurikun-1.5.0.tar.gz: lib/rectangle.dart <==
import 'dart:io';
import 'package:flutter/widgets.dart';
import 'package:flutter/services.dart';
import 'package:flutter/material.dart';
import 'constants.dart';
import 'ad_base.dart';
import 'adfurikun_plugin.dart';

enum AdfurikunRectangleCallback {
  onRectangleLoadFinish,
  onRectangleLoadError,
  onRectangleViewPlayStart,
  onRectangleViewPlayFinish,
  onRectangleViewPlayFail,
  onRectangleViewClicked
}

typedef AdfurikunRectangleListener(
    AdfurikunRectangleCallback? callback,
    String? appId,
    String? adNetworkKey,
    String? title,
    String? description,
    int? errorCode);

class AdfurikunRectangle extends AdfurikunAdBase {
  final double width;
  final double height;
  AdfurikunRectangleListener? listener;

  late final AdfurikunWidget _view;

  Map<String, AdfurikunRectangleCallback> _callbackMap = {
    CALLBACK_ON_RECTANGLE_LOAD_FINISH: AdfurikunRectangleCallback.onRectangleLoadFinish,
    CALLBACK_ON_RECTANGLE_LOAD_ERROR: AdfurikunRectangleCallback.onRectangleLoadError,
    CALLBACK_ON_RECTANGLE_VIEW_PLAY_START: AdfurikunRectangleCallback.onRectangleViewPlayStart,
    CALLBACK_ON_RECTANGLE_VIEW_PLAY_FINISH: AdfurikunRectangleCallback.onRectangleViewPlayFinish,
    CALLBACK_ON_RECTANGLE_VIEW_PLAY_FAIL: AdfurikunRectangleCallback.onRectangleViewPlayFail,
    CALLBACK_ON_RECTANGLE_VIEW_CLICKED: AdfurikunRectangleCallback.onRectangleViewClicked
  };

  AdfurikunRectangle(String appId, this.width, this.height) : super(appId, AD_TYPE_RECTANGLE) {
    _view = AdfurikunWidget(number, appId, adType, width, height);
    AdfurikunPlugin.invoke(method(METHOD_INIT), argsWithSize(width, height));
  }

  StatefulWidget adWidget() {
    return _view;
  }

  void load() {
    AdfurikunPlugin.invoke(method(METHOD_LOAD), args());
  }

  void loadWithTimeout(int timeout) {
    Map<String, Object> map = args();
    map[KEY_TIMEOUT] = timeout;
    AdfurikunPlugin.invoke(method(METHOD_LOAD), map);
  }

  void play() {
    AdfurikunPlugin.invoke(method(METHOD_PLAY), args());
  }

  @override
  void destroy() {
    super.destroy();
    AdfurikunPlugin.invoke(method(METHOD_DESTROY), args());
  }

  @override
  void notifyListener(MethodCall call) {
    if (listener != null) {
      AdfurikunRectangleCallback? callback = _callbackMap[call.method];
      String? appId = call.arguments[KEY_APP_ID];
      String? adNetworkKey = call.arguments[KEY_AD_NETWORK_KEY];
      String? title = call.arguments[KEY_TITLE];
      String? description = call.arguments[KEY_DESCRIPTION];
      int? errorCode = call.arguments[KEY_ERROR_CODE];
      listener!(callback, appId, adNetworkKey, title, description, errorCode);
    } else {
      print('AdfurikunRectangleListener is null');
    }
  }
}

==> adfurikun-1.8.0.tar.gz: lib/rectangle.dart <==
import 'dart:io';
import 'package:flutter/widgets.dart';
import 'package:flutter/services.dart';
import 'package:flutter/material.dart';
import 'constants.dart';
import 'ad_base.dart';
import 'adfurikun_plugin.dart';
import 'ad_network_error.dart';

enum AdfurikunRectangleCallback {
  onRectangleLoadFinish,
  onRectangleLoadError,
  onRectangleViewPlayStart,
  onRectangleViewPlayFinish,
  onRectangleViewPlayFail,
  onRectangleViewClicked
}

typedef AdfurikunRectangleListener(
    AdfurikunRectangleCallback? callback,
    String? appId,
    String? adNetworkKey,
    String? title,
    String? description,
    int? errorCode,
    List<AdNetworkError>? adNetworkErrorList);

class AdfurikunRectangle extends AdfurikunAdBase {
  AdfurikunRectangleListener? listener;

  late final AdfurikunWidget _view;

  Map<String, AdfurikunRectangleCallback> _callbackMap = {
    CALLBACK_ON_RECTANGLE_LOAD_FINISH: AdfurikunRectangleCallback.onRectangleLoadFinish,
    CALLBACK_ON_RECTANGLE_LOAD_ERROR: AdfurikunRectangleCallback.onRectangleLoadError,
    CALLBACK_ON_RECTANGLE_VIEW_PLAY_START: AdfurikunRectangleCallback.onRectangleViewPlayStart,
    CALLBACK_ON_RECTANGLE_VIEW_PLAY_FINISH: AdfurikunRectangleCallback.onRectangleViewPlayFinish,
    CALLBACK_ON_RECTANGLE_VIEW_PLAY_FAIL: AdfurikunRectangleCallback.onRectangleViewPlayFail,
    CALLBACK_ON_RECTANGLE_VIEW_CLICKED: AdfurikunRectangleCallback.onRectangleViewClicked
  };

  AdfurikunRectangle(String appId) : super(appId, AD_TYPE_RECTANGLE) {
    _view = AdfurikunWidget(number, appId, adType, 0, 0);
    AdfurikunPlugin.invoke(method(METHOD_INIT), argsWithSize(0, 0));
  }

  StatefulWidget adWidget() {
    return _view;
  }

  void load() {
    AdfurikunPlugin.invoke(method(METHOD_LOAD), args());
  }

  void loadWithTimeout(int timeout) {
    Map<String, Object> map = args();
    map[KEY_TIMEOUT] = timeout;
    AdfurikunPlugin.invoke(method(METHOD_LOAD), map);
  }

  void play() {
    AdfurikunPlugin.invoke(method(METHOD_PLAY), args());
  }

  @override
  void destroy() {
    super.destroy();
    AdfurikunPlugin.invoke(method(METHOD_DESTROY), args());
  }

  @override
  void notifyListener(MethodCall call) {
    if (listener != null) {
      AdfurikunRectangleCallback? callback = _callbackMap[call.method];
      String? appId = call.arguments[KEY_APP_ID];
      String? adNetworkKey = call.arguments[KEY_AD_NETWORK_KEY];
      String? title = call.arguments[KEY_TITLE];
      String? description = call.arguments[KEY_DESCRIPTION];
      int? errorCode = call.arguments[KEY_ERROR_CODE];
      List<AdNetworkError>? adNetworkErrorList = convertAdNetworkErrorList(call.arguments[KEY_AD_NETWORK_ERROR_LIST]);
      listener!(callback, appId, adNetworkKey, title, description, errorCode, adNetworkErrorList);
    } else {
      print('AdfurikunRectangleListener is null');
    }
  }
}
